==> bw-xml-synchws-4.0.8-sources.jar: org/bedework/synch/wsmessages/SynchIdTokenType.java <==

package org.bedework.synch.wsmessages;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 *         Id, url, token and opaque data for a synch operation.
 * 
 *         The opaque data is provided by the subscriber at subscribe
 *         time and passed back to the service.
 *       
 * 
 * <p>Java class for SynchIdTokenType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SynchIdTokenType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="principalHref" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="subscribeUrl" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="synchToken" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="opaqueData" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SynchIdTokenType", propOrder = {
    "principalHref",
    "subscribeUrl",
    "synchToken",
    "opaqueData"
})
public class SynchIdTokenType {

    @XmlElement(required = true)
    protected String principalHref;
    @XmlElement(required = true)
    protected String subscribeUrl;
    @XmlElement(required = true)
    protected String synchToken;
    protected String opaqueData;

    /**
     * Gets the value of the principalHref property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrincipalHref() {
        return principalHref;
    }

    /**
     * Sets the value of the principalHref property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPrincipalHref(String value) {
        this.principalHref = value;
    }

    /**
     * Gets the value of the subscribeUrl property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSubscribeUrl() {
        return subscribeUrl;
    }

    /**
     * Sets the value of the subscribeUrl property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSubscribeUrl(String value) {
        this.subscribeUrl = value;
    }

    /**
     * Gets the value of the synchToken property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSynchToken() {
        return synchToken;
    }

    /**
     * Sets the value of the synchToken property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSynchToken(String value) {
        this.synchToken = value;
    }

    /**
     * Gets the value of the opaqueData property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOpaqueData() {
        return opaqueData;
    }

    /**
     * Sets the value of the opaqueData property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOpaqueData(String value) {
        this.opaqueData = value;
    }

}

==> bw-xml-synchws-5.0.0-sources.jar: org/bedework/synch/wsmessages/SynchIdTokenType.java <==

package org.bedework.synch.wsmessages;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 *         Id, url, token and opaque data for a synch operation.
 * 
 *         The opaque data is provided by the subscriber at subscribe
 *         time and passed back to the service.
 *       
 * 
 * <p>Java class for SynchIdTokenType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SynchIdTokenType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="principalHref" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="subscribeUrl" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="synchToken" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="opaqueData" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SynchIdTokenType", propOrder = {
    "principalHref",
    "subscribeUrl",
    "synchToken",
    "opaqueData"
})
public class SynchIdTokenType {

    @XmlElement(required = true)
    protected String principalHref;
    @XmlElement(required = true)
    protected String subscribeUrl;
    @XmlElement(required = true)
    protected String synchToken;
    protected String opaqueData;

    /**
     * Gets the value of the principalHref property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrincipalHref() {
        return principalHref;
    }

    /**
     * Sets the value of the principalHref property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPrincipalHref(String value) {
        this.principalHref = value;
    }

    /**
     * Gets the value of the subscribeUrl property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSubscribeUrl() {
        return subscribeUrl;
    }

    /**
     * Sets the value of the subscribeUrl property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSubscribeUrl(String value) {
        this.subscribeUrl = value;
    }

    /**
     * Gets the value of the synchToken property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSynchToken() {
        return synchToken;
    }

    /**
     * Sets the value of the synchToken property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSynchToken(String value) {
        this.synchToken = value;
    }

    /**
     * Gets the value of the opaqueData property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOpaqueData() {
        return opaqueData;
    }

    /**
     * Sets the value of the opaqueData property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOpaqueData(String value) {
        this.opaqueData = value;
    }

}
